import 'package:flutter/material.dart';

import 'responsive_size.dart';

extension ResponsiveWidthDouble on double {
  /// [ResponsiveSizeUtils.width]
  double rWidth({
    double? maxWidth,
  }) {
    return ResponsiveSizeUtils.width(
      this,
      maxWidth: maxWidth,
    );
  }
}

extension ResponsiveWidthInt on int {
  /// [ResponsiveSizeUtils.width]
  double rWidth({
    double? maxWidth,
  }) {
    return ResponsiveSizeUtils.width(
      this.toDouble(),
      maxWidth: maxWidth,
    );
  }
}

extension ResponsiveHeightDouble on double {
  /// [ResponsiveSizeUtils.height]
  double rHeight({
    double? maxHeight,
  }) {
    return ResponsiveSizeUtils.height(
      this,
      maxHeight: maxHeight,
    );
  }
}

extension ResponsiveHeightInt on int {
  /// [ResponsiveSizeUtils.height]
  double rHeight({
    double? maxHeight,
  }) {
    return ResponsiveSizeUtils.height(
      this.toDouble(),
      maxHeight: maxHeight,
    );
  }
}

extension WidthFraction on double {
  /// [ResponsiveSizeUtils.widthFraction]
  double get rwFraction => ResponsiveSizeUtils.widthFraction(
        fraction: this,
      );
}

extension HeightFraction on double {
  /// [ResponsiveSizeUtils.heightFraction]
  double get rhFraction => ResponsiveSizeUtils.heightFraction(
        fraction: this,
      );
}

extension ResponsiveFontSizeDouble on double {
  /// [ResponsiveSizeUtils.responsiveFont]
  double rFont({
    double? maxFontSize,
  }) {
    return ResponsiveSizeUtils.responsiveFont(
      fontSize: this,
      maxFontSize: maxFontSize,
    );
  }
}

extension ResponsiveFontSizeInt on int {
  /// [ResponsiveSizeUtils.responsiveFont]
  double rFont({
    double? maxFontSize,
  }) {
    return ResponsiveSizeUtils.responsiveFont(
      fontSize: this.toDouble(),
      maxFontSize: maxFontSize,
    );
  }
}

extension FullWidth on BuildContext {
  /// [ResponsiveSizeUtils.fullWidth]
  double fullWidth() {
    return ResponsiveSizeUtils.fullWidth();
  }
}

extension FullHeight on BuildContext {
  /// [ResponsiveSizeUtils.fullHeight]
  double fullHeight() {
    return ResponsiveSizeUtils.fullHeight();
  }
}
